
#############################################
# producing graphs from the run results
# in order for this script to work the file
# results.csv must be present in the
# current directory
# it will then output the graphs used in the
# paper
#############################################


require(ggplot2)
require(reshape2)
require(easyGgplot2)

results <- read.table(file = 'results.csv',sep=',',header=TRUE)
# get only the relevant columns to plot and convert everything into a labeled data array
df <- data.frame(edges = results['edges'],coeff_flow = results['coeff_flow'],Eigen = results['Eigen'])
df <- melt(df,variable.name='method',id.vars='edges')

# golden ratio because reasons
phi <- 1.6180

ratio1 <- (max(df$edges) - min(df$edges))/(max(df$value)-min(df$value))

p1 <- ggplot(df,aes(edges,value,color=method)) +
  geom_point() +
  xlab('number of edges in the mesh') +
  ylab('run time time (s)') +
  labs(color='method:') +
  geom_smooth(size=.5) +
  theme(legend.position="bottom")

p1 + theme(plot.margin = unit(c(2,8,1,2),'mm'))
ggsave("timingsplot.pdf",width=phi*12,height=12,units='cm')


df2 <- data.frame(edges = log(results$edges)/log(10),coeff_flow = log(results$coeff_flow)/log(10),Eigen=log(results$Eigen)/log(10))
df2 <- melt(df2,variable.name='method',id.vars='edges')
ratio2 <- (max(df2$edges)-min(df2$edges))/(max(df2$value)-min(df2$value))

# labels
lm_eqn <- function(df,x,y){
  m <- lm(y ~ x, df);
  eq <- substitute(italic(y) == a + b %.% italic(x)*","~~italic(r)^2~"="~r2, 
                   list(a = format(coef(m)[1], digits = 2), 
                        b = format(coef(m)[2], digits = 2), 
                        r2 = format(summary(m)$r.squared, digits = 3)))
  as.character(as.expression(eq));                 
}

# subsets for calculating slopes
df3 <- subset(df2,method=='Eigen')
df4 <- subset(df2,method=='coeff_flow')


p2 <- ggplot(df2,aes(edges,value,color=method)) +
  geom_point() +
  xlab('log-number of edges in the mesh') +
  ylab('log-run time (s)') +
  labs(colour = 'method: ') +
  geom_smooth(size=.5) +
  theme(legend.position="bottom") +
  geom_text(x=2.5,y=1.5,label=lm_eqn(df3,df3$edges,df3$value),hjust = 0,size=7,parse=TRUE,aes(colour='Eigen'),show.legend = FALSE) +
  geom_text(x=2.5,y=2.4,label=lm_eqn(df4,df4$edges,df4$value),hjust = 0,size=7,parse=TRUE,aes(colour='coeff_flow'),show.legend=FALSE)

# # printing out
p2+ theme(plot.margin = unit(c(2,8,1,2),'mm'))
ggsave("log-log-timingsplot.pdf",width=phi*12,height=12,units='cm')